@@ -24,26 +24,30 @@ class CustomHttpRequest:
 
     async def request_url(self) -> Response:
         async with self.client as client:
-            status_code = 500
             try:
                 res = await client.get(url=self.url)
                 res.raise_for_status()
 
-            except HTTPStatusError as e:
-                status_code = e.response.status_code
-                res = self.create_error_response(status_code, e.response.text, "no_id")
-
             except HTTPError as e:
-                event_id = str(capture_exception(e))
-                print(f"event_id : {event_id}")
-                message = str(e)
-                res = self.create_error_response(status_code, message, event_id)
+                res = self.create_error_response(e)
 
             return res
 
 
     @staticmethod
-    def create_error_response(status_code: int, message: str, event_id: str) -> Response:
+    def create_error_response(e: any) -> Response:
+        status_code = 500
+        if hasattr(e, "response"):
+            message = e.response.text
+            status_code = e.response.status_code
+            if status_code <= 500:
+                event_id = "no_id"
+            else:
+                event_id = capture_exception(e)
+        else:
+            event_id = capture_exception(e)
+            message = str(e)
+
         return Response(
             status_code=status_code,
             json={"message": message, "sentry_event_id": event_id},
